;; Generated package description from dash.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "dash" "2.20.0.0.20260810.9" "A modern list library for Emacs" '((emacs "24")) :commit "d746dd9edcb67a108818beb0cdc78dc1cb466832" :authors '(("Magnar Sveen" . "magnars@gmail.com")) :maintainer '("Basil L. Contovounesios" . "basil@contovou.net") :keywords '("extensions" "lisp") :url "https://github.com/magnars/dash.el")
